{ pkgs, lib, ... }: {
  # Programs + packages with configuration --------------------------------------------------------------- {{{
  programs = {
    # a nicer cat
    # https://rycee.gitlab.io/home-manager/options.html#opt-programs.bat.enable
    bat = {
      enable = true;
      config = { style = "auto"; };
    };
    # Direnv, load and unload environment variables depending on the current directory.
    # https://direnv.net
    # https://rycee.gitlab.io/home-manager/options.html#opt-programs.direnv.enable
    direnv = {
      enable = true;
      nix-direnv.enable = true;
    };
    nix-index = { enable = true; };
    nushell = { enable = true; };
    ssh = {
      enable = true;
      matchBlocks."*".extraOptions = lib.optionalAttrs pkgs.stdenv.isDarwin {
        UseKeychain = "yes";
        AddKeysToAgent = "yes";
      };
    };
    vscode = {
      enable = true;
      # extensions = [ pijul-vscode ];
    };
    zoxide = { enable = true; };
  };
  # }}}

  # Other packages ----------------------------------------------------------------------------- {{{

  home.packages = builtins.attrValues ({
    inherit (pkgs)
    # GUI apps
      cinny discord-ptb lagrange obsidian slack zoom-us

      # System
      curl wget
      # lightweight session management
      abduco
      # archive tool
      atool
      # fancy version of `top` with ASCII graphs
      bottom
      # fancy version of `du`
      du-dust
      # fancy version of `ls`, fork of now-unmaintained `exa`
      eza
      # fancy version of `find`
      fd
      # wrapper for `ssh` that better at not dropping connections
      mosh
      # fancy version of `ps`
      procs
      # pipe progress viewer
      pv
      # command line file encryption
      rage
      # terminal color support testing
      terminal-colors
      # automatic command line fixes
      thefuck
      # extract RAR archives
      unrar
      # extract XZ archives
      xz

      # Dev stuff
      # source code line counter
      cloc
      # command line tools for digitalocean
      doctl
      # command line tools for fly.io
      flyctl
      # benchmarking tool
      hyperfine
      # json processor
      jq
      # task runner
      just
      # alternative to `git`
      pijul
      # better version of `grep`
      ripgrep
      # rust implementation of `tldr`
      tealdeer
      # reimplementation of `httpie` in rust
      xh

      # Useful nix related tools
      nixfmt nix-prefetch-git nix-tree
      # adding/managing alternative binary caches hosted by Cachix
      cachix
      # run software from nixpkgs without installing it
      comma
      # nix language server
      nil;
  } // lib.optionalAttrs pkgs.stdenv.isDarwin {
    inherit (pkgs)
    # useful macOS CLI commands
      m-cli
      # see /overlays/colors.nix
      is-dark-mode;
  });
  # }}}
}
